use eframe::egui;
use nalgebra::SMatrix;

pub fn mat_editor<const R: usize, const C: usize>(
    ui: &mut egui::Ui,
    mat: &mut SMatrix<f32, R, C>,
    id: &str,
    skip_last: bool,
) -> egui::Response {
    let mut any_change = false;
    let mut r = egui::Grid::new(id)
        .show(ui, |ui| {
            mat.row_iter_mut().enumerate().for_each(|(i, mut row)| {
                if !skip_last || i + 1 < R {
                    row.iter_mut().for_each(|item| {
                        any_change |= ui
                            .add(
                                egui::DragValue::new(item)
                                    .speed(0.01)
                                    .clamp_range(-10.0..=10.0),
                            )
                            .changed();
                    });
                    ui.end_row();
                }
            })
        })
        .response;

    if any_change {
        r.mark_changed()
    }

    r
}
